<?php


namespace Services;


use Exception\Login as Exception;
use Util\InstanceProvider;
use Util\Utilities;
use Util\RepositoryInstance;
use Zeedhi\Framework\Remote\FileUploader\Server;

class PrivacyPolicy
{
    private $fileServerFilesUrl;

    private $zhFileUploader;

    private $nrorg;

    /**
     * PrivacyPolicy constructor.
     * @param $fileServerFilesUrl
     * @param Server $zhFileUploader
     */
    public function __construct($fileServerFilesUrl, Server $zhFileUploader)
    {
        $this->fileServerFilesUrl = $fileServerFilesUrl;
        $this->zhFileUploader = $zhFileUploader;
        $this->nrorg = InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
    }

    public function uploadPrivacyPolicy($pdfPath)
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        $paramgeralRepository->updatePrivacyPolicy($this->getPrivacyPolicyPath($pdfPath), $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            $this->zhFileUploader->deleteFile($this->getPrivacyPolicyPathFileServer($paramgeral['DSARQPOLPRIV']));
        }
        return $this->getDataset(false, $this->getPrivacyPolicyPath($pdfPath));
    }

    public function removePrivacyPolicy()
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        $paramgeralRepository->updatePrivacyPolicy(null, $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            $this->zhFileUploader->deleteFile($this->getPrivacyPolicyPathFileServer($paramgeral['DSARQPOLPRIV']));
        }
        return $this->getDataset(true);
    }

    public function findPrivacyPolicy()
    {
        $data = array();
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $paramgeral = $paramgeralRepository->findParamgeral('DSARQPOLPRIV', $this->nrorg);
        if(!empty($paramgeral) && $paramgeral['DSARQPOLPRIV']) {
            return $this->getDataset(false, $paramgeral['DSARQPOLPRIV']);
        }
        return $this->getDataset(true);
    }

    public function findPrivacyPolicyByAuthentication($user)
    {
        $paramgeralRepository = RepositoryInstance::getParamgeral();
        $connectionParams = Utilities::getConnectionParamsParameter();
        if (!isset($connectionParams['useVpd']) || !$connectionParams['useVpd']) {
            $paramgeral = $paramgeralRepository->findPrivacyPolicyPath();
            if(count($paramgeral) == 1) {
                $paramgeral = $paramgeral[0];
            } else if($user) {
                $paramgeral = $this->getPrivacePolicyByUser($paramgeralRepository, $user);
            } else {
                return array(array('path' => null, 'status' => false));
            }
        } else {
            if($user) {
                $paramgeral = $this->getPrivacePolicyByUser($paramgeralRepository, $user);
            } else {
                return array(array('path' => null, 'status' => false));
            }
        }

        if(empty($paramgeral) || empty($paramgeral['DSARQPOLPRIV'])) {
            return array('path' => Utilities::getPrivacyPolicyPathParameter(), 'status' => true);
        } else {
            return array('path' => $paramgeral['DSARQPOLPRIV'], 'status' => true);
        }
    }

    private function getPrivacePolicyByUser($paramgeralRepository, $user) {
        $user = InstanceProvider::getLibUserDataRepository()->getOperatorByNmAccessOrEmail($user);
        if(empty($user)) {
            Exception::userNotFound();
        } else {
            return $paramgeralRepository->findPrivacyPolicyPathByAuthentication($user['ORGANIZATION_ID']);
        }
    }

    /**
     * @param $documentDefault
     * @param string $pdfPath
     * @return array
     */
    private function getDataset($documentDefault, $pdfPath = '')
    {
        $data = array();
        if($documentDefault) {
            $data[] = array(
                'pdfPath' => Utilities::getPrivacyPolicyPathParameter(),
                'documentDefault' => true
            );
        } else {
            $data[] = array(
                'pdfPath' => $pdfPath,
                'documentDefault' => false
            );
        }
        return $data;
    }

    public function getPrivacyPolicyPath($pdfPath)
    {
        return $pdfPath ? $this->fileServerFilesUrl . $pdfPath : null;
    }

    public function getPrivacyPolicyPathFileServer($pdfPath)
    {
        return $pdfPath ? str_replace($this->fileServerFilesUrl, '', $pdfPath) : null;
    }
}
